@@ -3,14 +3,17 @@ import os
 import redis
 
 
-def printer(msg, length_ctrl=True, fill_with='-', alignment='l', msg_head_tail=None, print_out=True, reflash=False):
+def printer(msg=None, length_ctrl=True, fill_with='-', alignment='l', msg_head_tail=None, print_out=True, reflash=False):
+    fill_with = '-' if not fill_with.strip() else fill_with.strip()
     try:
         length = os.get_terminal_size().columns
     except:
         length = 150
     al = {'l': '<', 'r': '>', 'm': '^'}.get(alignment)
-    if not msg_head_tail:
+    if not msg_head_tail and alignment == 'l':
         msg_head_tail = [' >>> ', '']
+    elif not msg_head_tail:
+        msg_head_tail = ['', '']
     if isinstance(msg_head_tail, str):
         msg_head_tail = [msg_head_tail, '']
     elif not isinstance(msg_head_tail, list):
@@ -19,16 +22,19 @@ def printer(msg, length_ctrl=True, fill_with='-', alignment='l', msg_head_tail=N
         except:
             pass
     msg_head_tail = [' {} '.format(x) if x else '' for x in msg_head_tail]
-    if not isinstance(msg, str):
-        msg = str(msg)
-    if length_ctrl:
-        if isinstance(length_ctrl, int) and length_ctrl > 1:
-            length = length_ctrl
-        if len(msg) > length:
-            msg = f" {msg[:(length - 10)]} ..."
-        else:
-            msg = f" {msg} "
-    msg = msg_head_tail[0] + msg + msg_head_tail[1]
+    if msg is not None:
+        if not isinstance(msg, str):
+            msg = str(msg)
+        if length_ctrl:
+            if isinstance(length_ctrl, int) and length_ctrl > 1:
+                length = length_ctrl
+            if len(msg) > length:
+                msg = f" {msg[:(length - 10)]} ..."
+            else:
+                msg = f" {msg} "
+        msg = msg_head_tail[0] + msg + msg_head_tail[1]
+    else:
+        msg = fill_with
     msg = ("{:%s%s%s}" % (fill_with, al, length)).format(msg)
     if print_out:
         if not reflash:
